# `pdf-lib-rs-py`

(wow what a mouthful)

Vibe-coded Python bindings to [`pdf-lib-rs`](https://github.com/asg017/pdf-lib-rs/), which itself is a vibe-coded Rust port of the excellent [`pdf-lib`](https://github.com/Hopding/pdf-lib).

I wouldn't trust this library much quite yet! But it suits my needs quite well.